# FAIR Neuroscience Tools
## What is FAIR?

The FAIR data principles were put forth by a diverse set of stakeholders representing academia, industry, funding agencies, and scholarly publishers in 2016 to provide guidelines for the improvement of the Findability, Accessibility, Interoperability, and Reusability of scholarly data. [(M. D. Wilkinson et al. Scientific Data
(2016))](http://www.nature.com/articles/sdata201618)

This wiki aims to highlight some of the efforts and tools that support the FAIR principles and are aimed to be used by the neuroscience community and some general resources as well.

## Other resource repositories

This repository is still under active development but there are a lot of other places on the web where you can read more about tools and standards supporting FAIR research, to mention a few:

* [INCF Website](https://www.incf.org/) - The International Neuroinformatics CoordinatingFacility (INCF) is an independent organization with a mission to develop, evaluate, and endorse standards and best practices that embrace the principles of Open, FAIR, and Citable neuroscience. They have adopted a rigorous and formal procedure for evaluating and endorsing community standards and best practices in support of the FAIR principles. [M. B. Abrams et al. Neuroinformatics (2021)](https://link.springer.com/article/10.1007/s12021-020-09509-0) You can find the endorsed tools [here](https://www.incf.org/resources/sbps).
* [FAIRsharing](https://fairsharing.org/) - This is a highly extensive resource of available community standards in different fields of STEM ([S.-A. Sansone et al. Nature Biotechnology(2019)](https://www.nature.com/articles/s41592-021-01156-w)). The existence of this resource corroborates the increasing adaptation of FAIR principles in research.
* [The Turing Way Handbook](https://the-turing-way.netlify.app/welcome.html) - This handbook developed and maintained by the Turing way community ([CC BY 4.0](https://creativecommons.org/licenses/by/4.0/)) although not targeted toward neuroscientists provides a fairly comprehensive roadmap for any data science project you might be interested in. The repository is not a listicle with introductions and instructions to all the tools but rather a very well-guided roadmap for your learning journey of doing '_reproducible, ethical and collaborative science_'.
* [Stanford center for reproducible neuroscience](https://reproducibility.stanford.edu/resources/) - Resource repository with tools by the center for reproducible neuroscience and also other community-driven initiatives.
* [Andy's brain book](https://andysbrainbook.readthedocs.io/en/latest/index.html) - Resource for fMRI beginners.
* [The Princeton Handbook for Reproducible Neuroimaging](https://brainhack-princeton.github.io/handbook/index.html) - The goal of this handbook is to provide a reference for best practices in fMRI research. This resource starts from the basics of neuroimaging to setting up a reproducible workflow to processing and analysis of your imaging data in a reproducible manner. Some of its contents are tailored to the use of Princeton infrastructure but most of the principles are widely applicable.
* [Tutorial: Workflows for reproducible research in computational neuroscience](https://rrcns.readthedocs.io/en/cns2012/#) - The tutorial explores the reasons for the difficulties often encountered in reproducing computational experiments, and some best practices for making computational neuroscience results more reliable and more easily reproducible. The tools covered in the tutorial are [Git](http://git-scm.com/), [Mercurial](http://mercurial.selenic.com/), [Sumatra](http://neuralensemble.org/sumatra) and [VisTrails](https://www.vistrails.org//index.php/Main_Page). Some of the tools used in this tutorial are rather old and unmaintained (Mercurial and VisTrails) but the premise and methods are still relevant.
## Tools, standards and resources

1. [Version Control](VCS.md)
2. [Data Structure Standards](Structures.md)
3. [Data Repositories](Repos.md)
4. [Data Analysis Tools](Analysis.md)
5. [Community Data Formats](Formats.md)
6. [Laboratory Information Management Systems](LIMS.md)
7. [Data Acquisition Softwares](DAQS.md)
8. [Workflow Management Systems](WorkflowManagement.md)